.\"**********************************************************************
.\"** Documentation of the the atari++ Emulator
.\"** Thomas Richter, THOR Software
.\"** $Id: atari++.man,v 1.20 2003/03/02 12:47:06 thor Exp $
.\"**
.\"**********************************************************************
.TH atari++ 6 "atari++ Emulator"
.SH NAME
atari++ \- a versatile extended emulator of Atari 8 bit machines
.SH SYNOPSIS
.B atari++
[-option value [-option value]...]
.SH DESCRIPTION
.I atari++
is an emulator for (now rather aged) Atari 8 bit computers. It emulates the
Atari800, Atari400, the 800XL and 600XL, the 65XE and 130XE and the Atari
5200 Game Console. The emulation is cycle-precise, that is \(lqon the
fly\(rq modifications of chip registers will be visible on the screen
immediately, emulating even programs using horizontal kernel tricks
correctly.

.I atari++
includes also emulation of an extended 1050 disk-drive, capable of single,
enhanced and double density and adds some frequent extensions found in
third-party hardware. The disk drive emulation supports disk images in the 
.I xfd
and 
.I atr
file format, and is also capable of loading binary load files (so called
.I exe
files) by emulating a mini Game-DOS whose disk layout is similar to Dos
2.0S. Most
.I exe
files wouldn't require to be loaded from a regular DOS therefore.

Emulation of printers is included as well. Print-out text is forwarded to
the standard printer tool, which defaults to the
.I lpr
printer front-end. The print-out command can be adjusted by means of the
command line options and the configuration files (see below).
.P
Additional features include a screen-snapshot, a complete machine state save
and load feature that allows you to stop and replay a game in a later
session and sound support by the
.I Open Sound System
(Oss) drivers. 
.P
Furthermore, to aid the developer, a simple system monitor using a
.I curses
terminal front-end has been integrated into the emulator. It offers several
features not available on the real hardware, as single stepping thru
programs and setting breakpoints, even in ROM code.
.P
Graphics output is either emulated within an
.I X11
window, or \- if available \- with the
.I SDL
library.
.SH OPTIONS
Quite untypical for unixoid systems, the 
.I atari++
options are not case sensitive, upper and lower case won't
matter. Furthermore, the order of the command line arguments doesn't matter
as well. The following options are supported:
.IP --help
prints all available options to the console.
.B NOTE:
Due to the dynamic build-up of the
.I atari++
components, the options these components become only available if the
corresponding component is activated as well. E.g, you won't see the 
X11 options with the SDL front-end activated.
.IP -h
similar to the above.
.P
All following options are of four kinds:
.B Numerical
options taking exactly one number as argument. They typically accept only
numbers within a limited range.
.B Boolean
options, taking the strings
.B on
.B yes
or
.B true
as positive and
.B off
,
.B no
or
.B false
as negative choices and
.B string
options that take either a file or a string as value. Last but not least,
.B selective
options that pick one out of several possible, mutually exclusive
choices.
.SS Global Options
This set of options does not belong to a specific part of the emulation
core, but rather influence the emulator as a whole.
.IP "-h or --help"
prints out the list of currently available options. This list does, however,
depend on the current configuration of the file as options for modules that
are currently not in use will not be shown on this list. For example, if
your
.B .atari++.conf
file selects the
.I X11
frontend for graphics output, the options for the
.I SDL
graphics support will not be shown. Unlike all other options, this option
does not take an argument.
.IP "-config filename"
Load an alternative configuration file into the emulator. This will override
the options from all other configuration files, but will be overridden by
the command line arguments itself.
.IP "-state filename"
Load a machine state snapshot file. This restores the machine state of a
previous
.I atari++
session by re-installing the memory conents and all hardware register
settings of the previous session. For more details about the snapshot
feature, see the
.B SNAPSHOT FILES
section below.
.SS Machine Type Options
The following options modify the overall emulation process, picks the
hardware to be emulated and the frontend how to perform graphics and sound
output.
.IP "-machine 800|XL|XE|5200"
Sets the type of machine to emulate. This is a meta-option that sets
suitable defaults for several other options, still allowing to override
these defaults with further commands. Hence, you'd be still able to run an
Atari XL machine with the Os of the Atari 800. The following models are
available:
.B 800
emulates the Atari 800 and its derivative, the Atari 400.
.B XL
emulates the Atari 800XL, the 600XL and the 65XE.
.B XE
emulates the Atari 130XE with a total of 128KByte memory. Last but not
least, the 
.B 5200
argument selects the emulation of the 5200 game console.
.IP "-frontend X11|SDL"
Defines which graphical front-end should be used. Currently, the
.B X11
and the
.B SDL
front-ends are supported. Whereas the X11 front-end runs in a window on the
desktop, the SDL front-end opens a full-screen emulation that is more
suitable for games play. Typically, the SDL front-end provides better
performance unless you need to scale up the output with the -pixelwidth or
-pixelheight options. Then, X11 performs noticeably better.
.IP "-sound HQOSS|OSS|WAV|SDL"
Sets the audio front-end used to generate audio output. For the
.B OSS
and
.B HQOSS
front-ends, an
.I Open Sound System
compatible driver is required, or no sound whatsoever will be
available. Sound synthesis will be very close to the real sound output and
will be at good quality, though some CPU power is required to guarantee
continuous output without dropouts. In general, the
.B HQOSS
driver is preferably since it requires less precise implementations of the
Oss standard and provides excellent quality for synthesized speech.

The main intention of the
.B WAV
front-end is to record the sound output as sampled sound in a
.I .wav
encoded file in optimum quality. To allow you to listen to in-game sounds,
this front-end also offers a \(lqplay-back\(rq option that also generates
sound output thru an OSS compatible sound output, though this output is of
less quality than that of the dedicated
.B HQOSS
module. Even though the play-back sound may contain some \(lqblips\(rq or
drop-outs, the quality of the recorded audio within the
.I .wav
file will be perfect and very close to the original. 

The
.B SDL
audio generation is the last option, and comes close in quality to that of
the
.B HQOSS
driver, though it is more likely to generate drop-outs for highly loaded
systems. SDL is the best in portability as SDL exists on a variety of
systems. The SDL driver also emulates software speech correctly.

.IP "-monitoroncrash bool"
If this boolean option is enabled, then the emulator enters automatically
the built-in monitor in case the 6502 CPU crashes due to a corrupt
program. Note that these crashes are not due to bugs in the emulator, but
rather due to flaws in the emulated program, i.e. a \(lqreal\(rq Atari would
have crashed in the same situation. If this option is disabled, then a
warning gets printed and the user menu is entered. It is then up to you to
either reset the emulation or to launch the monitor manually. This option
defaults to
.B false
,i.e. the monitor is not entered by itself. 

For details about the system monitor, see the 
.B MONITOR
section below.

.IP "-acceptlicence bool"
If enabled, then it is understood that you read and agreed to the licence
conditions under which Atari++ is delivered, and the licence conditions are
no longer presented on startup.

.SS CPU Options
The following options control the emulation of the 6502 CPU:
.IP "-wsyncpos 0..114"
A technical option that defines the horizontal position where
ANTIC releases the CPU if it has been formerly blocked by a
.B STA WSYNC.
This is counted in CPU cycles clocks from the falling edge of the
horizontal sync. It defaults to 103 cycles and is adjustable within a range
of 80 to 114 color clocks.
.IP "-traceonreset bool"
This boolean option is useful for debugging. If enabled with the
.B on
argument, the CPU enters trace mode on a reset, entering the build-in
monitor immediately.
.SS GTIA Options
The following options modify the emulation process of the video signal
generator, the
.I Graphics Television Interface Adaptor
chip:
.IP "-videomode PAL|NTSC"
Defines whether the emulated GTIA should either identify itself as 
.B PAL
or as
.B NTSC
chip. Some games read this value and modify their timing accordingly. 
.IP "-artifacts bool"
This boolean option controls whether GTIA should emulate color artifacts
that are caused by video system. If set to
.B on
, the video rendering will detect hi-lo and lo-hi transitions for
high-resolution graphics and text mode and will generate pseudo-colors
similar to a real TV. These artifacts are limited to NTSC systems for the
real hardware and are not as effective nor very visible for the PAL
hardware; the emulator, however, displays them regardless of the emulated
video mode. Some games require this setting to look properly. If set to
.B off
, artifact generation is disabled as for a higher quality monitor or for the
PAL video system. This also makes text more readable and less blurry, it also
speeds up the emulation process somewhat and is better suited for
text-oriented software.
.IP "-beforedisplaycycles 0..80"
A technical setting that defines the number of half-color clocks GTIA from
the DLI detection cycle up to the first cycle generating video data, and
hence specifies the relation between the video signal and CPU cycles. This
option can be used to fine-control programs that alter chip registers within a
horizontal scan line. It adjusts the timing of the horizontal kernel these
programs run to archive the effect, and as such moves the horizontal
position of the register change leftwards or rightwards on the screen. It
defaults to 28 half-color clocks, or equivalently seven CPU cycles.
.IP "-beforedlicycles 0..16"
The number of cycles the CPU runs freely from the end of the horizontal
blank to the position where ANTIC will detect and generate the display list
interrupt. This option is identical to the ANTIC option of the same name,
and should be set to the same numerical value as otherwise the length of a
horizontal scan line will not be emulated precisely. On the command line,
the GTIA and the ANTIC option of this name will always be setup identically,
but within the user menu, independent adjustment is possible, though not
desirable. 

Note that this option is specified in CPU cycles, unlike the former, which
is specified in half color clocks. A CPU cycle is four half color clocks,
and hence two color clocks wide. Hence, from the return of the horizontal
blank, the CPU first runs for an amount of cycles specified until ANTIC may
detect a DLI by this option, though generation of video data is then further 
delayed by an additional number of color clocks controlled by the option 
described immediately above.

This option defaults to eight cycles.
.IP "-playertrigger.0 all|players|missiles|none"
The first out of four otherwise identical options sets the ability of player
zero to generate collisions with other objects on the screen. Note that this
.B does not
change the ability of player zero to
.B detect
collisions itself, though. It just removes the ability of other players or
missiles to collide with it.

If this option is set to
.B all,
then player zero can create collisions with all other objects, for the
.B players
setting, only collisions with other players are generated and missiles never
see any collisions with player zero. For the
.B missiles
setting, the situation is reversed and only missiles can detect collisions
to player zero. Finally, for the
.B none
argument, player zero generates no collisions at all.
.IP "-playertrigger.1 all|players|missiles|none"
works similar to the above except that it changes the ability of player one
to generate collisions.
.IP "-playertrigger.2 all|players|missiles|none"
changes the abilities of player two and, finally,
.IP "-playertrigger.3 all|players|missiles|none"
modifies the collision abilities of player three. 

Note that there are no options to modify the collision abilities of a
missile since it has none in the real hardware. A missile can never create 
a collision with a player itself, or any other object. Rather, the situation
is somewhat reversed from the expected logic: A player creates a collision
to a missile, and hence, its ability to collide with missiles must be turned
off to avoid detection of player-missile collisions.
.IP "-playfieldtrigger.0 all|players|missiles|none"
Modifies the abilities of playfield zero, i.e. the first foreground color,
to generate collisions to other objects. Similar to the above set of four
options, playfields can be allowed to generate collisions to all objects,
players only, missiles only or no objects at all.
.IP "-playfieldtrigger.1"
Triggers the ability of playfield one to generate collisions; otherwise,
similar to the above.
.IP "-playfieldtrigger.2"
The same again for playfield two.
.IP "-playfieldtrigger.3"
the same once again for playfield three.
.SS ANTIC Options
The following options control the DMA controller and the playfield graphics
generator chip:
.IP "-videomode PAL|NTSC"
This option is intentionally identical to the GTIA option of the same name
and controls the video system ANTIC should emulate. As for ANTIC, this
switch controls the height of the video output. For
.B PAL
, a total of 312 lines is generated, and for
.B NTSC
, only 262 lines of output are displayed. Note that not all lines are
available for graphics as the vertical retrace takes up some of them.
.IP "-beforedlicycles 0..16"
This option has the same function than the identical option of the GTIA
module, though it controls the other side of the medal within ANTIC: It
controls the number of CPU cycles from the end of the horizontal blank 
ANTIC requires to generate the non-maskable display-list interrupt. This
option will be set in parallel to the similar GTIA option on the command
line, but may be adjusted independently by the grahical menu, though it is
recommended to adjust both options in parallel here as well. This option
defaults to eight cycles.
.SS POKEY Options
The next set of options influences the sound generation. For sound output,
the
.I Open Sound System
driver for your sound card, more specifically,
.B /dev/dsp
must be available. Alternatively, sound output can be written into a 
.I .wav
file and replayed later by a suitable tool, e.g. XMMS. The emulator will not 
leave sound emulation to
.I SDL
due to its touchy nature. The following set of switches will not
change the output of the sound, but rather the emulation of
the POKEY chip generating the audio signal that is further processed by the
OSS module described below.
.IP "-volumegain 1..3"
Controls the overall volume of the POKEY output. 3 is loudest and 1 is
noisiest.
.IP "-audioclip 1..64"
Defines an audio output clip level truncating the maximal amplitude of the
audio output. Due to some nonlinearities in the POKEY sound build-up, output
is cut and truncated as a specific level resulting in sound effects that can
be emulated by this option. It defaults to 64, i.e. no truncation, and can
be lowered up to 1.
.IP "-serindelay 1..256"
Defines the number of horizontal blanks required for a byte arriving at the
serial port to fill the
.B SERIN
register of POKEY. This switch henceforth limits the speed of the serial
port emulation for transfers into the emulated Atari hardware. This option
is adjustable from 1..256 horizontal blanks and defaults to 15.
.IP "-seroutdelay 1..256"
Similar to the above, this counts the number of horizontal blanks required
for the
.B SEROUT
buffer latch to become available for the CPU again. The valid settings range
from one to 256 lines and default to 15.
.IP "-serxmtdelay 1..256"
Quite similar to the above, this measures the time for the
.B SEROUT
register to become completely empty, resulting in a
.B SERXMTDONE
interrupt signal from POKEY. As above, valid settings range from one to 256
lines and default to 15. You'd rarely have to adjust these timings as they
match closely the behavior of the real hardware.
.SS PIA Options
The following set of options modify the emulation of the
.I Peripheral Interface Adapter
chip.
.IP "-mathpackcontrol bool"
enables control of the
.B MATHPACKDISABLE
signal thru bit 6 of PIA port B. This function is only required for some
dedicated hardware of the author of this program and should be otherwise
left alone.
.SS MMU Options
The following options control the features of the
.I Memory Management Unit.
For the 800 and 400, no real MMU chip has been used. Rather, the MMU is a
set of standard logic gates that control the memory map of the system. From
the 800XL and up, all these gates have been integrated into a dedicated
hardware chip called the MMU. Regardless of these technicalities, the memory
management logic is controlled by the following options:
.IP "-4kextended bool"
Enables additional 4K of memory in the range of 0xc000..0xd000 for the Atari
400 and 800 models. For the XL and XE, this memory region contains parts of
the ROM and is never available. For the 400 and 800, this region is
otherwise blank.
.IP "-axlonram bool"
Enables emulation of Axlon type RAM expansions that are controlled by
address 0xcfff. These RAM disks have pages of 16K each that are mapped into
the memory from 0x4000 to 0x8000.
.IP "-axlonbankbits 0..8"
Defines the number of bits within the page control port 0xcfff of the Axlon
RAM disk emulation used for the page selection. The more bits are enabled,
the more banks are available. Each additional bit doubles the number of 16K
banks.
.IP "-xebankbits 0..8"
This option is only available if the emulator is setup to the 130XE machine
type. Then, it defines the number of PIA port B RAM bits used to define the
selected/active bank. The 130XE uses two bits for selecting the bank, and
hence has four pages of 16K, making a total of 64K extended RAM. Note that
the more bank bits you enable here, the less compatible the resulting
emulation will be to a \(lqstraight\(rq 130XE. Specifically, you loose the
proprietry PIA Port B \(lqMathPackDisable\(rq at three bits, the selftest at
four bits, the Basic ROM at five bits, separate Antic access at six bits, OS
Rom mapping at seven bits and CPU access control at eight bits.
.SS OS Options
The following options control the emulation of the
.I Operating System ROM
and related features, most notably various Os patches that are installed
into it.
.B NOTE:
ROM images are not included in the distribution of Atari++ due to copyright
restrictions.
.IP "-osapath filename"
Gives the location of the OS A ROM image. This file contains a simple dump
of the memory area 0xd800..0xffff of the original first revision Os of the
Atari 800 and 400, or a dump from 0xf800..0xffff for the 5200 console.
.IP "-osbpath filename"
Specifies the location of the second revision for the Atari800 and 400 ROM
image file.
.IP "-osxlpath filename"
Specifies the location of the Atari 800XL and later model ROM image. This
ROM image contains the memory areas 0xc000..0xd000, the self-test that can
be mirrored to 0x5000..0x5800, and the math-pack and the upper ROM area from
0xd800 to 0xffff, in that order. This is also the natural order within the
real ROM chip, which is twice as large as for the former Atari models.
.IP "-os5200path filename"
specifies the location of the 5200 ROM image.
.P
.B NOTE:
At least one ROM image must be available. If none of these options has been
given on the command line, then Atari++ will try to locate them itself. It
therefore looks into the directory \(lqroms\(rq in the current
directory. For the XL operating system, it tries to find a file named
\(lqatarixl.rom\(rq in this directory. For the Os A resp. Os B image, files
named \(lqatariosa.rom\(rq resp. \(lqatariosb.rom\(rq are searched, and
loaded if found.
.P
The emulator will also look for ROM images itself. Precisely, it will check
a subdirectory named \(lqroms\(rq for the files \(lqatariosa.rom\(rq, 
\(lqatariosb.rom\(rq or \(lqatarixl.rom\(rq that represent ROM images of the
OsA, OsB and XL Rom, respectively.
.IP "-ostype OsA|OsB|OsXL|5200"
Defines which kind of ROM shall be loaded into the system. Note that this
need not to be identical to the type of machine you are emulating, even
though this is the default and probably the most useful selection. The 5200
console is an exception: Its ROM will not be accepted by anything but the
5200 machine, and any other machine type will not accept the 5200 ROM. This
is because the mapping of the hardware differs between the \(lqregular\(rq
Atari 8 bit systems and the 5200 console, making the ROMs non-portable.
.IP "-installpdevice bool"
Selects whether a patched
.B P:
device handler should be installed that redirects printer output directly to
the printer component. If this patch is not installed, printer emulation
will be re-routed thru the
.I SIO
emulation described below. This will work as much as this direct patch, but
might be somewhat slower.
.IP "-installhdevice bool"
If enabled, the
.B C:
cassette handler is replaced by an emulator specific
.B H:
(Host) handler that mirrors parts of the host filing system into the
emulator. The 
.B H:
device understands all major CIO commands and most XIO commands, following
the conventions of DOS 2.0S, e.g.
.B RENAME
and
.B LOCK
XIOs are available by its DOS 2.0S command IDs. More about the
.B H:
device can be found below in a specific section.
.IP "-installhasdisk bool"
Changes the device letter under which the host handler will be installed. By
default, the handler will be called
.B H:,
but if this flag is set, then the handler will be inserted as
.B D:
giving you emulated disk access. Programs that entirely access the disk thru
this handler, for example BASIC programs, will then run off the host filing
system.
.IP "-h1dir filename"
Defines the directory where the first unit of the
.B H:
device should be anchored. Files in this directory are accessible thru
.B H1:
or 
.B H:,
provided the host handler is patched in by the option above.
.IP "-h2dir filename"
Specifies the anchor path for the second unit of the
.B H:
handler, accessible by
.B H2:.
.IP "-h3dir filename"
The host directory for the third unit of the
.B H:
handler.
.IP "-h4dir filename"
Finally, the directory for the fourth unit of the host handler.
.IP "-siopatch bool"
If enabled, then serial input/output handling is routed thru an Os patch to
the emulated devices directly instead of using the detour thru the POKEY
emulation and the emulation of the serial port. This speeds up serial
access, especially disk drive access, noticeably, but might cause
compatibility problems with some critical software that expects precise
timing and exact behavior of the serial hardware.
.SS CARTRIDGE Options
The next set of options allows to insert a cartridge into the emulated
cartridge slot of the system. Currently, only the left cart slot of the
Atari 400 and 800 , resp. the one and only cart slot of all later models is
emulated. 
.IP "-cartpath filename"
specifies the filename of the cartridge image to load.
.IP "-carttype none|8k|16k|32k|oss|ossb|sdx|xegs|bountybob"
specifies the type of cartridge to load. Unfortunately, the emulator cannot
figure out the cart type itself in all cases just by looking at the image
file. Therefore, this option has to be given along with the option above.

.B None
is a dummy option that just disables the cart, and hence ignores the above
option altogether.

.B 8K
emulates an 8K sized plain cartridge that is mapped into the memory from
0xa000 to 0xbfff.

.B 16K
emulates a plain 16K cart occupying the memory region from 0x8000 to 0xbfff.

.B 32K
emulates 32K cartridges of the 5200 game system. This option and the 32K rom
images will not be accepted for all other machine types and hence remains
unavailable then.

.B Oss
emulates an Oss super cartridge that is mirrored into the memory map from
0xa000 to 0xbfff, but is 16K sized internally. The cartridge therefore
provides a bank-switching mechanism thru the
.B CARTCTRL
system component, as it consists internally of two ROM chips, called 
.B RomA
and
.B RomB
in the following. The lower region 0xa000 to 0xafff is variable and can be
bank-switched, the upper region 0xb000 to 0xbfff is hard-wired to the
upper part of
.B RomA.
The following table shows the mapping for the lower region:

.TS
l l.
CartCtrl Port	Rom mapped at 0xa000 to 0xafff
_
0xd500	RomB Lo
0xd502 or 0xd506	Blank
0xd501,0xd503 or 0xd507	RomA Lo
0xd504 or 0xd509	RomB Hi
0xd508 and up	disable cart
.TE

.B OssB
is also an Oss super-cart except that the cartridge ROM has been dumped to
disk in a different order and hence the addressing of the cartridge ROM
contents is different. If the 
.B Oss
option does not work, try this option instead.

.B SDX 
emulates a 64K large ROM image with eight banks mapped into the
region of 0xa000 to 0xbfff.

.B XEGS
emulates a variable size XEGS cartridge. This cart type occupies 16K of
memory within the address space of the 6502 CPU but consists of several
banks that can be mapped into the 0x8000...0x9fff region.

.B BOUNTYBOB
emulates the 40K sized BountyBob cartridge for the 5200 games system. This
cartridge uses a very unique bank switching mechanism that requires its own
emulation provided by this option.

.IP "-rtime8 bool"
enables or disables the emulation of the RTime-8 pass-thru cartridge. This
this a cartridge rom that contains a battery buffered real-time clock and
passes the cartridge slot connections thru to be able to use the real-time
clock together with other cartridges. The default is not to enable the
real-time clock cartridge.

.SS BASIC Options
The following options control the function of the
.B BASIC Rom
of the Atari 800XL and later models. Since the Atari 800 and 400 models do
not come with a built-in BASIC, these options are ignored for the earlier
models; you'd need to insert the BASIC as a regular 8K cartridge for them.
Furthermore, whether the basic is mapped for the XL and later series
depends on whether the
.B Option
console key is held down during bootstrap. This option is part of the
keyboard options below, even though it influences the working of the basic
ROM for the XL and XE series.
.IP "-basicpath filename"
Specifies the file name where the BASIC rom image shall be read from. This
is a simple 8K memory dump of the ROM appearing at 0xa000 to 0xbfff.
.B NOTE:
Due to copyright restrictions, no BASIC ROM image is included in the
distribution of Atari++.
.IP "-usebasic bool"
Specifies whether the BASIC ROM shall be made available to the emulator. If
set to
.B on,
then the BASIC will be enabled. On the XL or XE series, the
.B Option
console key must
.B NOT
be held down during bootstrap as well to make the BASIC appear.
.SS SIO Options
The
.I Serial Input/Output
module is a specific part of the operating system taking care of serial
communication. The Atari++ emulation component of the same name hence
controls the low-level emulation features of all devices emulated on 
the serial port, hence the disk-drives and the printer. The emulation of the
serial port can be bypassed by the -siopatch option described in the 
.B OS Option
section above, giving a noticeable speedup for disk-drive and printer, but
possibly also causing compatibility problems for software that depends on
precise timing or side-effects of the Os implementation.
You usually need not to care about the settings below as they closely match 
those of typical serial hardware anyhow.
.IP "-serincmddelay 0..240"
The amount of time taken by a serial device to accept a command frame. This
time is given in horizontal blanks. It defaults to 50 lines.
.IP "-readdonedelay 0..240"
The time taken for a serial read command to complete. For the disk-drive
emulation, this would emulate the time required to read a sector from disk
up to the time where the first byte of the sector arrives at the port. This
setting also defaults to 50 lines.
.IP "-writedonedelay 0..240"
Required time to complete a write command. For the disk-drive, this is the
time taken from the last byte of a sector arriving at the drive up to the
time where the disk-drive sends the acknowledgement frame. This setting
defaults again to 50 lines.
.IP "-formatdonedelay 0..1024"
Required time to format a disk in a disk-drive, measured as the time from
issuing the command up to the time where the first byte of the sector status
map arrives at the serial input. This is again given in horizontal lines. 
Since the Os assumes that the timing of formatting is a bit more relaxed
than the regular reading time \- yes, formatting is a read command for the
Atari \- this is a separate option, defaulting to 400 horizontal lines.
.SS PRINTER Options
The next set of options controls the printer emulation. Commands and data 
enter this emulation either by the SIO, or directly by the
.B P:
handler should it be patched into the Os. See the
.B OS Options
for more details about this.
.IP "-printcommand file"
Specifies the command used to print out text on the host system. The text
arriving at the emulated printer will wait in a queue and will be flushed
regularly, appearing at the
.B STDIN
of this command. Typically, this should be either
.B lpr
or
.B lp
, depending on the printing system you use at your machine.
.IP "-enableprinter bool"
Enables or disables the emulated printer. If set to
.B off,
the printer will not react on any SIO commands as if it has been turned
off. Otherwise, printing will be allowed.
.IP "-transposeeol bool"
The Atari doesn't use the regular
.B LF
character to separate lines on the printer output. Rather, it uses the
character 0x9B (CSI in the ANSI set, named EOL on Ataris) to separate
lines. Hence, for printing text, EOL has to be transposed into line feeds by
this option, which is also the default. However, for graphics output,
this character transposition will change the meaning of the graphics data
send to the printer, and will hence distort the graphics.
.B NOTE:
Currently, Atari++ does not include the emulation of a graphics
printer. All control and graphics sequences sent out to the emulated printer
will be spooled directly into the print command without interpreting them
further.
.IP "-flushdelay 0..60"
This specifies the delay in seconds from the last data arriving at the
emulated printer until the collected text/graphics are printed out. Hence,
if data is printed at a rate lower given by this delay, they will appear in
separate spool jobs. This delay defaults to five seconds.
.SS SPEED Options
The following set of options controls the timing of the emulator. Several
other factors influence the maximum speed, though. First of all, the
graphical front-end of the emulator might be more or less performing. For
full-screen emulation, the
.I SDL
front-end is performing provided no pixel upscaling is used. In all other
cases, the
.I X11
frontend offers higher speed. This is not the fault of the emulator, but
rather a matter of the poor performance of SDL.
Furthermore, the sound emulation has some impact as well. For software
speech emulation, high sampling rates and slim buffers are a must, causing
some software overhead and higher CPU loads. For maximizing the speed,
either run the
.I X11
frontend on 1x1 or 1x2 pixel sizes and reduce the quality of the audio
output.
.IP "-refreshrate 1..16"
This option specifies the screen refresh rate; this could be also understood
as the screen drop rate. If set to one, the emulator tries to display every
screen. If set to two, every other screen is dropped, etc. Hence, this
option defines the maximal possible refresh rate under optimal
conditions. This option defaults to one.
.IP "-maxmiss 1..16"
Unlike the above, this option controls how much frames the emulator may miss
to keep the emulation speed. If this is set to one, the emulator never
misses a frame, but looses much speed on slow systems. If set to a value
higher than one, at most the specified number of frames might be dropped to
keep up the refresh rate set by the option above. Hence, it does not hurt to
select a higher maxmiss rate on a fast machine, but it will keep up the
speed for more complex graphics on slower machines as well at the cost of
loosing some frames.
.IP "-videodmode PAL|NTSC"
Intentionally identical to the same option of the ANTIC and GTIA emulation,
this selects the frame rate based on the video output mode. For a
.B PAL
machine, this selects a freshmode of 50 frames/second, for a
.B NTSC
machine, the emulator will try to generate 60 frames/second.
.SS DISKDRIVE Options
The following set of options controls the emulation of up to four disk
drives. The diskdrive options consist of a base name, a dot and the unit
number specifying the unit of the disk drive they control. Hence, all the
following options exist four times, and just differ by the digit behind the
dot.
.IP "-enable.1 bool"
Enables or disables the first diskdrive. If set to
.B off,
the first drive will not react as if it has been turned off, otherwise it
will be turned on. The default is to enable the first drive and to disable
all others.
.IP "-image.1 filename"
Specifies the path to an image file to be loaded into the drive. The Atari++
emulator supports several kinds of image files: First, raw disk images that
keep the contents of the disk sector by sector. These files are typically
identifies by their extender
.I .xfd.
The second available format is the so called
.I .atr
format implemented by several other Atari emulators. It consists of a tiny
header describing the format and the size of the disk plus the sector image.
The third format supported by Atari++ is that of Atari 
.I binary load files
or short, so called
.I .exe
files. These files consist of a two 0xff byte header plus address
information where to place the data to load. These files are booted by
writing them as DOS 2.0S files onto disk, toghether with a minimal game DOS
header that bootstraps the 
.I .exe
format. Note that no full DOS will be available for these files, though this
emulation is sufficient for most
.I .exe
based games right away. Last but not least, Atari++ also supports
.I .dcm
images, which have been prepared by the \(lqDisk Communicator\(rq program
and are (slightly) compressed. Similar to the
.I .exe
files, Atari++ cannot re-compress these. Therefore, disk images of this type
are marked write-protected, making writes to these disks fail. All of the
above disk image types can be compressed by means of the 
.B gzip
program; Atari++ will then uncompress them on demand as soon as the image
gets loaded. Since it does not re-compress images, these disks also always
end up write-protected.

.IP "-protect.1 bool"
Enables or disables the write-protection of the inserted disk. If set to
.B on,
the disk image will be write-protected as if the write-protection notch has
been covered on a physical disk. The emulator also write-protects disk
images automatically if the corresponding image is marked non-writeable by
the protection bits of the host operating system, or if the disk is build up
for the
.I .exe
binary load file emulation, or comes in the already compressed
.I .dcm
Disk Communicator format. Similarly, all
.I .gz
compressed images are write-protected, no matter what the original file
format has been.

.P
Similar disk drive options exist for drives two to four by replacing the
digit
.B 1
in the above list by the appropriate drive number.
.SS JOYSTICK Options
Joystick emulation for Atari++ consists of two layers: First of all, the
emulation of the corresponding port at the emulated hardware, and second the
generation of sigals to feed data into this emulated port. For that, Atari++
uses the concept of a generic
.I input device
consisting of two axes and two buttons, abstracting from the real physical
device on your machine to generate the input. For a physical (analogue) PC
joystick, the meaning of the two axis and two buttons should be obvious, but
other sources for the abstract input device exist as well, e.g. the mouse or
the keyboard.

The following set of options do not control the physical input devices, but
rather select how the emulator should make use of this abstraction layer,
whereever it comes from, to form digital joystick input. Hence, the
following set of options controls the emulation of the emulated joystick
port on input from an abstract input device.

Similar to the diskdrive options, all joystick options exist four times, now
numbered from zero to three. The digit behind the dot in the option name
defines the joystick port this option controls. For the Atari 800 and 400,
all four ports are used by the emulator, for the XL and later models, only
the ports 0 and 1 are mapped to the emulated hardware, similar to their
physical counterparts.

.IP "-joystick.0.sensitivity 0..32767"
This option sets a threshold that must be crossed by the abstract analogue
joystick input to detect a joystick movement on the emulated joystick
port. The lower the number, the higher the sensitivity. The abstract input
devices generate axis movements from -32767 to 32767, the default of this
option is that a movement of 8192 units on this scale is required to
generate an input signal.
.IP "-joystick.0.port devicename"
Defines the name of the abstract device that should be connected to the
port. Currently, the following devices exist:
.RS 4
.IP "MouseStick.0"
Uses the mouse on your host system as abstract input device, with the
horizontal and vertical position of the mouse pointer forming the horizontal
and vertical axis of the abstract input device connected to the port. There
is only unit 0 of this device.
.IP "KeypadStick.0"
Uses the keypad on the keyboard of the host system forming the abstract
input device. Digits 8,4,6 and 2 generate maximal axis movements in top,
left, right and down movement, respectively; keys 7,9,1 and 3 move in the
corresponding diagonal directions. The 0 and
.B Enter
map to button 0 of the joystick. There is \- quite obviously \- only
unit 0 of the keypad-stick.
.IP "AnalogJoystick.0"
Uses the (real) analog joystick connected to the port controlled by the
.B /dev/js0
device to form the abstract input of the device. Which physical axis forms
which abstract axis is controlled by the analog joystick options described
below, but the default mapping is the obvious: Each physical axis maps to
the same abstract axis, and buttons 0 and 1 map to their abstract
counterparts. 
Atari++ accepts up to eight physical joysticks by replacing the digit
.B 0
in the above option by 1 to 7 for further joysticks that are then connected
to the corresponding joystick devices.
.IP "DigitalJoystick.0"
Uses a (real, antique) Atari Joystick connected to an analog PC joystick
port by means of the \(lqEl Cheapo\(rq joystick adapter of the author. 
This adaptor maps the digital input lines of
a digital joystick to the buttons 1 to 4 of an analog joystick, and maps the
one and only button by a resistor array to axis 0. As above, some parameters
of this interface can be setup by the digital joystick options described
below. Similar to above, the signals generated by this hardware are then
read thru the standard
.B /dev/js0
Linux interface, and up to eight digital joysticks can be emulated this way,
accessing the devices
.B /dev/js1
to
.B /dev/js7.
.B NOTE:
You need to build some additional hardware to make use of this abstract
device, but you get perfect Atari feeling as a bonus.
.IP "SDLAnalog.0"
Similar to \(lqAnalogJoystick.0\(rq except that the joystick position isn't
read from the kernel interface directly, but rather indirectly thru the SDL
library. This makes absolutely no difference except that on some systems
only the kernel interface is available, whereas on others only the SDL
interface can be used.
.IP "SDLDigital.0"
Works exactly the same as \(lqDigitalJoystick.0\(rq except that the joystick
movements are reported thru the SDL library rather than thru the kernel
interface. Causes no difference in usage and options otherwise.
.IP None
Do not connect any device to this joystick input and read it as
\(lqcentered, no button pressed\(rq all the time.

.RE 1
Similar to the diskdrive options, the joystick options exist four times with
the unit numbers
.B 0
to
.B 3.
The default for the abstract input device is to use the keypad stick for
joystick zero and leave all other joysticks and paddles unconnected.

.B NOTE:
The 5200 console system does not use standard Atari digital joystick
input. Instead, analog joysticks connected to the paddle inputs are
used. It is therefore mandatory to define the input devices of the first two
paddles, paddle 0 and 1, to have an input device for the 5200 console. The
digital joystick inputs defined by the options above
.B WILL NOT WORK.

.SS PADDLE Options
The following set of options control the emulation of up to eight paddles
that can be connected to the emulator. Similar to the above, the emulation
requires an abstract input device to read the input of the emulated paddle
from; paddle emulation uses only axis zero of this abstract device to form
the paddle input, but requires buttons zero and one for the emulation of the
two paddle buttons.

.B NOTE:
The paddles on the Atari machines use the joystick input lines for the
paddle buttons. For that reason, paddles and joysticks should not make
use of the same input device.

.B NOTE:
For the 5200 system, the controller is connected as a paddle and hence
these - and not the joystick options - must be defined.

As above, the following options exist several times, with the digit
.B 0
replaced by 1..7 for all other paddle units. Whereas the Atari 800 and 400 allow
this maximal number of eight paddles, inputs 4..7 are not available on a
real Atari XL or XE. However, the Atari++ allows connection to these paddle
inputs regardless of the emulated host input as the corresponding input
lines are otherwise unused on the real hardware either.

.IP "-paddle.0.sensitivity 0..32767"
Adjusts the sensitivity of the paddle and hence the movement necessary for a
full paddle rotation. Note that the abstract input device generate movements
on a scale of -32767 to 32767.
.IP "-paddle.0.invert bool"
Since paddle input has no natural orientation, this option allows you to
invert the meaning of the input device position. Since some games interpret
paddle positions just opposide to others, this flag helps you out as it 
changes left movement to right, or upwards movement to downwards movement.
.IP "-paddle.0.port devicename"
Defines which abstract input device to use to feed the paddle emulation. The
very same devices as for the joystick emulation are available here, though
pure digital devices as the keyboard or the digital joystick device are not
very usable for paddle emulation. Since an abstract input device provides
two axis and two buttons each, it makes sense to map one input device to two
paddle inputs: For that reason, each even paddle number maps to the first
axis and the first button, and each odd paddle number maps to the second
axis and button of each abstract input device.
.SS LIGHTPEN Options
Atari++ also allows emulation of the lightpen as a kind of analog input
device. Though rarely used, the corresponding input lines at ANTIC are
available and can be feed by this emulation component. There is only one
lightpen device available, though its other options are very similar to the 
paddle emulation.
.IP "-lightpen.sensitivity 0..32767"
Defines the sensitivity of the lightpen and hence the factor/adjustment
between the real physical device and the emulated position of the lightpen
on the screen.
.IP "-lightpen.port devicename"
Specifies which abstract input device to connect the emulated lightpen
to. The list of available devices is identical to the list of devices for
all other gameport like input, please see the
.B JOYSTICK Options
section above.
.SS ANALOGJOYSTICK Options
Unlike the
.B JOYSTICK Options,
the following set of options describes the mapping of a true analog joystick
connected to one of the joystick device drivers to the abstract input device
that forms the basis for either joystick, paddle or lightpen input. Hence,
it defines the layout of the
.B AnalogJoystick
devices that can be connected to the above emulation components.

Similar to most above options, the following options exist several times
with the digit
.B 0
replaced by the unit of the corresponding device. Hence, the analog PC
joystick controlled by
.B /dev/js1
is setup by options similar to those above with a 
.B 1
replacing the
.B 0.
.IP "-button.0 button.1|button.2|button.3|button.4"
Defines which button of the physical joystick shall map to the button zero
of the abstract input device. The default is to connect the first button of
the physical joystick to the first button, i.e. button zero, of the abstract
device.
.IP "-haxis.0 xaxis.1|yaxis.1|xaxis.2|yaxis.2"
Specifies the axis of the physical joystick that should emulate the
horizontal axis of the abstract analog joystick device. The default is the
first horizontal axis of the physical joystick.
.IP "-vaxis.0 xaxis.1|yaxis.1|xaxis.2|yaxis.2"
Similar to the above for the vertical axis of the abstract device. The
default is, of course, the first vertical axis.

.SS SDLANALOG Options
This is a modified
.B AnalogJoystick
interface that reads joystick positions thru the SDL library instead using
the kernel interface directly. Its configuration options are identical to
that of the
.B AnalogJoystick
interface and are hence not described here again.

.SS DIGITALJOYSTICK Options
The next set of options is used to setup the digital joystick input and the
\(lqEl Cheapo\(rq Joystick input adapter that can be used to connect a 
true Atari digital joystick to the analog gameport input of the PC.
This option set also exists several times, once for each available gameport
detected in the host system. Once again, replace the digit
.B 0
by the unit number of the corresponding device the joystick is connected to.
.IP "-upbutton.0 Button.1|Button.2|Button.3|Button.3"
Defines which of the four joystick buttons on the analog gameport acts as
the input for the upwards movement line. The default is button three.
.IP "-downbutton.0 Button.1|Button.2|Button.3|Button.3"
Similar to the above for the downwards movement. The default is button one.
.IP "-leftbutton.0 Button.1|Button.2|Button.3|Button.3"
Selects the button that acts as the left movement input. This defaults to
button four.
.IP "-rightbutton.0 Button.1|Button.2|Button.3|Button.3"
Selects the button for right movement input. The default is button two.
.IP "-triggeraxis.0 XAxis.1|YAxis.1|XAxis.2|YAxis.2"
Selects the analog gameport axis that reads the digital joystick button
input. The default is that the digital fire button is connected to the first
horizontal axis.
.IP "-triggerthres.0 -32768..32768"
Since the digital button is read by the game port as an analog input, the
digital signal arrives as a numerical value between -32768 and 32767 at the
digital joystick device of the emulator. The above option sets the threshold
by which the button is read as pressed resp. released. The precise values
depend of course on the resistance network that is connected to the analog
gameport line, but the default for 16384 works fine for the author's
hand-soldered adaptor.
.IP "-inverttrigger.0 bool"
With this switch, the fire button input line reading can be inverted,
i.e. active inputs are read as released fire buttons and vice versa. This
shouldn't be necessary with the author's interface. The default is hence
.B off.
.SS SDLDIGITAL Options
This is just a slightly modified
.B DigitalJoystick
interface that connects to SDL instead to the kernel interface. All its
options are identical, please refer to the above list for details.

.SS OSSHQSOUND Options
In the following, we give a set of options to control the generation of
audio thru the OSSHQ driver, making use of the
.I Open Sound System
kernel interface or an equivalent emulation, e.g. by
.I ALSA.
Rather than the 
.B POKEY Options,
these options concern the quality of the samples generated by the POKEY
emulation and its built-up for OSS. For audio output to work properly, you 
need to have an
.I Open Sound System
compatible audio driver available, and you need to have permission to access
the
.I /dev/dsp
device.

Note that generating audio samples with high quality has a non-neglectable 
impact on the CPU load. If your machine has problems keeping up with the
natural framerate, or if the CPU load is too high, try to lower these
settings, use a different audio front-end, or disable sound output alltogether.
.IP "-enablesound bool"
Enables or disables the generation of audio output. The default is the
enable the audio generation, unless no audio output device is available
which then disables audio output.
.IP "-enableconsolespeaker bool"
Enables or disables the emulation of the Atari console speaker. The Atari Os
generates keyboard click sounds and the buzzer by means of this
speaker. Some games also use the console speaker for speech output.
.IP "-consolespeakervolume 0..64"
Sets the output volume of the console speaker. Setting this to zero
effectively disables the output, and setting this to a value higher than 32
may cause distortion with regular
.B POKEY
audio output. This option ranges from zero to no up to 64 for maximal volume
with the default being 32.
.IP "-audiodevice filename"
Specifies the name of the audio device to send the samples to. This device
must accept all
.I Oss
specific ioct() settings. It defaults, naturally, to
.B /dev/dsp.
.IP "-samplefreq 4000..48000"
The sampling frequency in Hz by which samples should be generated, and hence
the limiting frequency for the audio signals. The higher this value is, the
higher are the possible frequencies that can be emulated, and the more
natural the sound plays. Frequencies higher than 16000 are required for
software speech output, but otherwise a frequency limit of 8000 Hz is enough
for all other sound effects. The default is 44.1kHz, the CD replay frequency.
.IP "-fragsize 2..16"
This is a technical setting that allows to specify the size of an audio
buffer fragment. These fragments get filled sample by sample 
and are transmitted to the replay hardware as soon as they are full and the
hardware is capable of playing another sample. If they are too small, the
buffer has to be refilled too often and you might hear drop-outs since the
computation cannot keep up with the audio replay. If they are too long, the
audio latency becomes too high and the sound is no longer synchronized with
the video out. This option does, however, not specify the fragment size itself, but
rather the exponent to the base of two, i.e the true fragment size will be
two to the power of this exponent. The default for this option is 8, i.e. a
fragment size of 256 bytes. You'd rarely need to play with this setting.
.IP "-numfrags 6..256"
The number of buffers, each of the size given by the above argument, to be
used for audio sample generation. More buffers reduce the likelyhood of
drop-outs, but increase the latency. The default are 16 buffers, more is
rarely useful.

.SS OSSSOUND Options
The
.B Oss
driver is a less complex frontend for the
.I Open Sound System
audio interface, though it requires a very precise implementation of it.
Some emulations, e.g.
.I ALSA
might not be suitable for this frontend, and it rarely provides better
quality than
.B HQOss.
Since it provides quite similar options as well, we only describe most of
them roughly and refer to the
.B HQOss
frontend for further details.

.IP "-enablesound bool"
Enables or disables the generation of audio output. 
.IP "-enableconsolespeaker bool"
Enables or disables the emulation of the Atari console speaker.
.IP "-consolespeakervolume 0..64"
Sets the output volume of the console speaker.
.IP "-audiodevice filename"
Specifies the name of the audio device to send the samples to; this is
typically
.B /dev/dsp.
.IP "-samplefreq 4000..48000"
The sampling frequency in Hz for the audio output.
.IP "-refillfreq 20..48000"
The frequency in Hz by which the audio samples are recomputed by the emulator. If
this is set to a relatively low value, but the sampling frequency is high,
then quite a lot of samples are computed in one go, but the updating period
by which these samples are matched to the true
.B POKEY
output is rather low. This refill frequency must be lower than the sampling
frequency above. For software speech generation, a refill frequency of 15700
proved most effective. For regular sound output, this frequency can be much
lower. Note that for software speech output, the audio kernel interface must 
meet the specifications of the
.I Open Sound System
architecture precisely. Some emulations, e.g.
.I ALSA
fail here. Try to use the
.B HQOss
frontend in this case; in most cases, it is capable of providing better
quality anyhow.
.IP "-fragsize 2..16"
The exponent for the base of two giving the size of an audio buffer fragment
in bytes. This is similar to the fragment size of the
.B HQOss
frontend and is discussed in more detail above.
.IP "-numfrags 1..256"
The number of buffers to be used for audio sample generation. For two
buffers, this means that audio output is double-buffered. More than four
buffers are rarely useful for this driver, making this the default.
.SS WAV Options
The WAV frontend is the alterantive audio output module that rather records
the generated sound than to play it; or at least, this is its main
intention: WAV also offers playback of the recorded sound, though due to
timing restrictions the quality of this sound is - sometimes noticably - 
worse than that of the Oss or HQOss module and the sound that got recorded in 
the final
.I .wav
file. As said, the quality of the output file will be perfect.

.IP "-enablerecording bool"
Enables or disables the recording to the
.I wav
output file. If enabled, the emulator starts recording as soon as the
emulated machine starts running, though the recorded file is disposed and
re-written from scratch on a cold-reset, e.g. generated by the
.B F7
key. To record game music, you'd best first enable the recording, then start
the game, let the music play and interrupt the music by entering the
configuration menu with the
.B F1
shortcut. Then turn off recording. This will leave the recorded file intact.
.IP "-enableplayback bool"
Enables or disables the playback of the recorded data. If this option is
enabled, the WAV frontend will also play the music over an OSS compatible
sound driver. It is typically a good idea to enable this option as well
whenever it is available, i.e. whenever an OSS sound driver is in the
system. Note, though, that the quality of the sound output might be of
noticably worse quality than that of the recorded sound within the output
file.
.IP "-enableconsolespeaker bool"
Similar to the option of the same name for the OSS sound front-end, this
option enables or disables the generation of sound thru the console
speaker. It is typically used for the keyboard-clicks and the buzzer-sound.
.IP "-consolespeakervolume 0..64"
Sets the volume of the console speaker if enabled. This option defaults to
32.
.IP "-outputfile filespec"
Defines the full path of the
.I .wav
output file to record the sound in. If this option is not given, then this
file name defaults to \(lqout.wav\(rq.
.IP "-audiodevice device"
Sets the name of the OSS sound device. This is typically \(lq/dev/dsp\(rq,
which is also the default setting for this option.
.IP "-samplefreq 4000..48000"
Sets the sampling frequency in Hz for the recorded
.I .wav
file, and by that also the sampling frequency of the played-back audio
output. The smaller, the less CPU power is required and the shorter the
output file becomes for recording the same timespan of music, but the worse
the quality gets. This option defaults to 15700 Hz which is the best
compromise between quality and data size. Much higher frequencies make
little sense and do not improve quality noticably.
.IP "-fragsize 2..16"
sets similar to the OSS front-end option of the same name the exponent for
the size of the fragment for audio playback. It has no influence whatsoever
on the output file whatsoever, but rather modifies the behaivour of audio
playback only.
.IP "-numfrags 1..256"
sets the number of audio fragments (buffers) for audio playback, similar to
the option of the same name of the OSS front-end. It has no influence on the
recorded samples.

.SS SDLSound Options
The last of the three possible audio front-ends is generation thru the
.I Standard Direct Media Library,
or short
.I SDL,
all provided you have an SDL library and the required development files 
installed on your host. The quality of the SDL output is close to that of
the
.B HQOss
frontend, though due to the different driver architecture, it is
unfortunately more likely for the SDL driver to generate drop-outs. It
furthermore requires longer fragments and has therefore a higher latency, but it
is very portable as SDL exists on a variety of platforms. 

.IP "-enablesound bool"
enables or disables the sound generation thru SDL, similar to the same
option for the OSS and WAV audio front-ends.
.IP "-enableconsolespeaker bool"
will toggle the console speaker emulation on or off. The emulation is
enabled by default.
.IP "-consolespeakervolume 0..64"
adjusts the volume of the console speaker. This setting defaults to a medium
volume of 32.
.IP "-samplefreq 4000..48000"
adjusts the sampling frequency for the audio generation in Hz = samples per
second. Higher sampling frequencies provide closer sound output emulation,
but also enlarge the CPU load on the system. The sampling frequency defaults 
to 44100Hz, i.e. CD quality. You might have to lower this setting on weaker
systems.
.IP "-fragsize 2..16"
selects the size of an audio output buffer as the exponent for the base of
two. The smaller the fragment size, the more often the audio output will get
updated to reflect the audio register setting of the POKEY chip, and the
more natural audio output will become. If the fragment size is
too small, then audio output will degrate quickly, though, as the emulation
will then no longer be able to refill the output buffers in time. The
optimal setting for this value is around nine, which is also the default.

.SS X11 Options
The next set of options controls the
.I X11
graphical frontend of the Atari++ emulator, all provided it has been
selected with the
.B -frontend X11
option. Otherwise, the control options of the selected frontend apply
instead.
.IP "-privatecmap bool"
If set to
.B on,
then Atari++ will emulate its own color map for the emulation window
output. This is only required if you run it on a 8 bit display and the
emulator further complains that it couldn't allocate enough free pens. The
downside of this option is that the colors will get wrong as soon as the
mouse pointer leaves the emulator window on an 8 bpp display, but at least
you get a display with proper colors otherwise. 

This option is not at all useful for 16 bpp or any other true-color displays
as the color mapping will be correct all the time otherwise. Therefore, the
default for this option is
.B off.
.IP "-syncx bool"
A boolean flag that describes whether the X11 frontend shall try to keep the
display output in sync with the emulator. If set to
.B off,
all rendering operations will be asynchronous, possibly causing some lag
between the gameplay and the display. The downside of enforcing synchronous
graphic renderning by setting this to
.B on
is that the display refresh must wait for the X server to perform the
refresh and to notify the client about it, adding the turn-around times and
the net transfer overhead to the display refresh time. It is therefore rarely a
good idea to enable this option.
.IP "-renderindirect bool"
If set to
.B on,
then all rendering happens indirectly to an off-screen pixmap in a first
step, then blitting the pixmap in a second step back to the screen. This has
the downside of being slower by requiring an additional transfer step, but
it makes the display refresh smoother as well as the rendering operation
itself remains invisible. Since it makes emulation slower, this option
remains
.B off
by default.
.IP "-screenbase filename"
Selects a filename base for the screen dumps. If a screendump is requested,
a counter and a file type extender is appended to this name and the screen
contents are saved to this file. Currently, screen dumps are saved in the
.I Portable Pixmap (ppm) Format
that is readable by most Linux/Unix tools, e.g. by xv and gimp. The default
filename is \(lqScreenDump\(rq.

.IP "-pixelsize 1..8"
This option spezifies the magnification degree by which the pixels of the
emulated scren are rendered to the X11 display. The default of the pixelsize
option is
.B 2,
i.e. a single pixel of the Atari display is rendered as a 2x2 pixel of the X
window showing the emulation. Depending on the hardware driver of your
graphics board, enlarging the pixelsize might be almost for free with the X11
frontend. 
.IP "-leftedge 0..64"
Sets the horizontal position of the first Atari pixel that gets displayed
within the X11 window. The pixels left to this pixel are not made
visible. This option is useful either to align the size of the X window to
the natural size of the screen the window is contained in, to hide the
leftmost pixel junk caused by the horizontal ANTIC scrolling, or to remove
the hardware border of the window, similar to the operation performed by
some TVs. This option defaults to 16, just enough to make the
.B HSCROLL
artefacts invisible.
.IP "-topedge 0..64"
Sets the first row of the ANTIC display to render to the X11 window. This is
otherwise identical to the -leftedge option except that it works in vertical
direction. The default of this option is zero.
.IP "-width 320..480"
Sets the total amount of pixels to render into the screen and hence the
inner dimension of the X window. Reducing this width can be either useful to
fit this window into the screen, or to avoid some pixel junk at the right
edge of the ANTIC display. The default width is 352 pixels.
.IP "-height 192..248"
Sets the height of the window in emulated pixels. Since the lowest lines are
always left blank anyhow, they need not to be rendered. Therefore, this
option defaults to 240.

.SS SDL Options
The next option set controls the layout of the alternate emulator frontend
driven by the
.B Simple Direct Media Library,
or short, SDL. This library allows fullscreen output, though its overall
performance is lower as soon as it requires to upscale the pixels. The SDL
frontend is activated by the
.B -frontend SDL
switch, and only then the following options apply:
.IP "-leftedge 0..64"
Similar to the
.I X11
Option of the same name, this selects the first visible emulator pixel on
the SDL screen. This option defaults to 16.
.IP "-topedge 0..64"
Specifies the first visible row on the screen. The default is to start the
display at row 0.
.IP "-width 320..480"
The width in emulator pixels of the screen to render. The default is 352.
.IP "-height 192..248"
The height of the emulated display. The default is to drop some lines at the
bottom end since they are always blank anyhow: 240 lines are rendered by
default.
.IP "-pixelwidth 1..8"
Set the width of one emulator pixel in SDL pixels. The default is that one
emulator pixel is represented by one pixel on the SDL screen. Setting this
to values larger than two easely degrades the emulator performance.
.IP "-pixelheight 1..8"
Set the height of one emulator pixel in SDL pixels. As already said above,
the default is one. Pixel heights larger than two typically slow down the
emulator too much to be useful.
.IP "-screenbase filename"
Defines a base file name similar to the
.B X11
screenbase option for screen dumps. The filename of the screen dump is, as
above, formed by a counting number and the extender of the file
format. Currently, screen snapshots are saved as PPM images.
.SH CONFIGURATION FILES
Atari++ is not only controlled by its huge amount of command line
parameters. It is also adjustable by configuration files. These
configuration files contain the very same options than the command line
parameters, except that there is only one option per line, an equals = sign
separates option from value, and the minus-sign in front of the option is
missing. Additionally, empty lines and comments starting with the hash-mark
# are allowed. The following example shows a typical configuration file:
.P
.nf
#
# This is the config file for the atari++ emulator
#
HoldOption      = true
Artefacts       = off
Enable.1        = on
Protect.1       = on
SIOPatch        = on
InstallPDevice  = on
SampleFreq      = 44100
RefillFreq      = 15700
NumFrags        = 4
Joystick.0.Port = DigitalJoystick.0
.fi
.P
The Atari++ emulator knows three configuration files: The system specific
configuration file, residing at /etc/atari++/atari++.conf, the per-user
specific configuration file at ~/.atari++.conf and the per-directory
configuration file at ./.atari++.conf. Each later configuration file
overloads the defaults of the former, and the command line arguments finally
overload all of them. This way, the least frequently adjusted options should
go into the configuration file in the home directory, with system specific
settings in /etc.
.SH KEYMAP
The Atari++ emulator uses the following keymap:
.IP F1
This key enters the graphical configuration menu. The usage of this menu
should be quite obvious as all the options are named as in this manual and
sorted under the same topics. The menu is left by the topmost
.B Prefs
topic which also allows loading and saving the settings and entering the
monitor.
.IP F2
is mapped to the
.B Option
console key.
.IP F3
is mapped to the
.B Select
console key.
.IP F4
is mapped to the
.B Start
console key.
.IP F5
is the
.B Help
key that is otherwise only available on the XL and XE hardware.
.IP F6
is the
.B Reset
console key. Its function differs a bit amongst various models. For the
Atari 800 and 400, this key just signals a special NMI interrupt at ANTIC,
and the Os resets the system manually. For the XL and XE, this signal is
really connected to the CPU reset line. Atari++ emulates this behaivour.
.IP F7
coldstarts the system as if it has been turned off and on again. Hence,
unlike F6, this is a true coldstart and not a warmstart.
.IP F8
emulates the
.B Break
key, used to stop listings and BASIC programs.
.IP F9
requests a screen dump. Where this screendump goes is a matter of the
.I -screenbase
command line option.
.IP F10
aborts the emulator immediately, similar to closing the window.
.IP "F11 and Pause"
pauses the emulator. Pressing
.B F11
again continues the emulation.
.IP F12
enters the on-line monitor that is described below.
.IP "Home/Clear"
emulate the
.B Shift+<
sequence, enforcing a clear screen.
.IP "Insert"
inserts a blank character under the cursor by emulating
.B Ctrl+>.
If pressed together with
.B shift,
a blank line is inserted at the current line position.
.IP "Del"
removes a single character under the cursor by emulating a
.B Ctrl+BS
keyboard sequence.
.IP "Cursor Keys"
move the cursor in the indicating direction by holding either
.B +,*,-,=
and the
.B Ctrl
key down. This works fine most the time except for the
.I DDT
debugger which requires these keys pressed without
.B Ctrl
for window movement. Do not use the separate cursor keys but the above keys
directly for DDT.
.IP "Esc"
emulates, as expected, the
.B ESC
key on the Atari keypad.
.IP "Keypad keys 7,8,9,4,5,6,1,2,3"
are part of the \(lqkeypadstick.0\(rq device and a possible emulation source
for joystick input.
.IP "Keypad keys 0 and Enter"
emulate the joystick button of the device as well.

All other keys have their natural key binding except for the 5200 game
console which is explained below. This binding is given by the current keyboard
layout; this means especially that the keyboard layout is language specific
and does not necessarely match the layout of the Atari keyboard. E.g. for a
german keyboard, the keys for \(lqy\(rq and \(lqz\(rq work as printed on
the PC keyboard, and not as for the (american) Atari keyboard layout. I
currently consider this as an advantage.

.SS KEYBOARD INPUT FOR THE 5200
Keyboard input on the 5200 game system is considerably different as this
console does not have a keyboard, but a small numberic pad on each of its
controllers. This pad consists of the numbers zero to nine, the asterisk 
\(lq*\(rq, the hash-mark \(lq#\(rq and the buttons labelled \(lqStart\(rq,
\(lqPause\(rq and \(lqReset\(rq. Furthermore, the joysticks have two buttons
instead of one, and are actually analog joysticks using the paddle input
lines, see above. The current emulator uses the PC keyboard for all
additional keys and does currently not distinguish between the various
keypads. A button pressed on the PC keyboard will be read as coming from all
game controllers at once. A future version of
.I atari++
may possibly use a different scheme.

The following keyboard keys act differently on the 5200 system:

.IP "F2"
is the \(lqReset\(rq key on the keypad of the controller. This key is in no
way any kind of hardware reset and is dissimilar to the \(lqreal\(rq
hardware reset which is still triggered by
.B F6.
Instead, this key is just an ordinary key that must be read by the loaded
game, typically bringing you back to the setup screen.
.IP "F3"
is the \(lqPause\(rq key on the keypad. This is also a purely software
driven feature the game may or may not support.
.IP "F4"
is the \(lqStart\(rq key; it typically launches the game.
.IP "keys 0..9"
activate the corresponding keypad keys.
.IP "H or #"
emulates the hash-mark on the keypad controller key. Since the hashmark is
not available on all native PC keyboards, the
.B H
is available as an replacement.
.IP "S or *"
emulates the asterisk on the controller keypad. Similarly, the
.B S
is a suitable emulation for native keyboards with a hard-to-reach asterisk
key.
.IP "Shift"
acts as the second trigger button on all external controller keypads. 
.IP "F2 thru F12"
act as usual, see the list above.
.IP "all other keys"
are blind and perform no operation in the 5200 emulation mode.

.SH SNAPSHOT FILES
The atari++ allows you to make a snapshot of the complete machine state
anytime within a game, to save this state to a file and to restart the game
later on from this position. This is not only useful to interrupt a game
temporarely - maybe because you've better things to do in the mean time - it
also helps to try hard game puzzles several times. 

To create a snapshot file, enter the menu by pressing the
.B F1
key on your keyboard, pick the
.B Prefs
item on the left hand side list and enter the name of the state file into
the bottommost gadget labelled \(lqSave State To\(rq. 

To restore a machine state, i.e. to load the snapshot file, use the gadget
\(lqLoad State From\(rq right on top of it, or the command line option
.B -state filename
expecting the name of your snapshot file.

It is important to understand that the snapshot file contains only the
part of the inner machine state that
.B is not covered by the configuration file. 
For example, the snapshot file will
.B NOT
contain the currently active ROM image as this image is already sufficiently
specified by the configuration. Hence, if your configuration at the time you
made the snapshot differs from your default configuration, you should also
save that configuration, and load it along with the snapshot.
.B Snapshot files extend configuration files,
they are not independent from the emulator configuration.

.SH THE H: HANDLER
The emulator provides an optional interface from the emulated Atari to the
host environment by the
.B H:
handler that makes parts of the filing system of the host visible within the
emulation. To make use of this handler, it has to be enabled by the
.B -InstallHDevice on
command line option or a similar option within the configuration files. This
option will replace the
.B C:
cassette interface - which is rarely, if ever, useful - by the host
interface filehandler. This handler provides four units, named
.B H1:
to
.B H4:
opening four directories of the host system within the emulator. These
directories are configured by the
.B -H1Dir
to
.B -H4Dir
command line options, expecting path name(s) to host system directories.

.SS FILE NAMES AND PATTERN MATCHING
Similar to the standard file management systems DOS 2.0S and upper, the 
.B H:
handler automatically resolves patterns within filenames. The following
wildcards are supported:
.IP *
matches a sequence of any, possibly zero, length of any characters, quite
similar to the bash or the csh.
.IP ?
matches one single character.
.IP -
Matches any character and ignores the rest of the pattern.

Unlike the standard file management systems, the dot \(lq.\(rq has no
special meaning for the
.B H:
device except that file names are truncated to eigth characters in front and
three characters beyond it. This is a backwards compatibility feature to be
able to run most Atari Os compliant programs on the
.B H:
device without additions.

The handler will furthermore ignore cases when comparing the requested file
name with a file name on the host system. Files generated by the emulator
will use lower case for convenience.

.SS COMMAND SET
The
.B H:
handler supports the following IO commands:
.IP "CMD 3: OPEN"
used by the BASIC
.I OPEN #channel,aux1,aux2,\(lqH:filespec\(rq
command. The
.I aux2
specifier will be ignored, valid
.I aux1
values are:

.TS
l l.
aux1	function
_
4	open for read-only
6	open the directory
7	open the directory
8	create for write-only
9	open for append write-only
12	open for read, write and append
13	create for read, write and append
.TE

This follows closely the DOS 2.0S conventions with the addition that mode 12
is able to write past EOF and mode 13 also creates files. Mode 7 is an
addition that was made for compatibility of DOS 2.XL by the author.

The
.I filespec
follows the file name convention explained in the previous subsection;
the directory listing generated by codes 6 and 7 will be formatted similar
to the DOS 2.0S output for the same request, but the amount of free sectors
will always show up as \(lq999\(rq. This is because there is basically no
visual storage limit for a tiny Atari file system inside a Unix/Linux
workstation. Files that are not user-writeable appear as \(lqlocked\(rq and
are marked with an asterisk in the first column. Similarly, file locking and
unlocking changes the user-writeable protection bit of the host system.
.IP "CMD 5: GET RECORD"
Reads characters up to an
.B EOL
character, or up to the buffer end, into a buffer. This is a standard
command supplied by all handlers. This implements the BASIC
.I INPUT #channel,var
and related commands.
.IP "CMD 7: GET CHARACTERS"
Reads a block of characters into a buffer. This is a standard command,
consult the Atari technical manual for details. Not reachable from BASIC.
.IP "CMD 9: PUT RECORD"
Writes characters up to an
.B EOL
or up to the end of the buffer into the opened stream. Also part of the
standard command set. Not reachable from BASIC, but related to
the BASIC command
.I PRINT #channel,data.
.IP "CMD 11: PUT CHARACTERS"
Writes a block of characters into a stream. A standard command. Not
reachable within BASIC, but related to
the BASIC commands
.I PUT #channel,value
and
.I PRINT #channel,data.
.IP "CMD 12: CLOSE"
Releases the given stream, closes the file on the host system and frees all
buffers. This command is considered harmless on streams already closed. This
implements the BASIC
.I CLOSE #channel
command.
.IP "CMD 13: STATUS"
Requests the status of the given stream. It returns status code 133 if the channel
is not open, status code 1 if the channel generated no error, status code 3
if you are about to read from the
.B EOF
on the next go, or the last error should the stream be in an error condition
otherwise. This follows standard conventions.
.IP "CMD 32: RENAME"
Implements the BASIC
.I XIO 32,#channel,aux1,aux2,\(lqH:oldname,newname\(rq
command. Note that the file specification of this command consists of an
existing filename, a comma \(lq,\(rq, and a new file name. This command
attempts to rename the existing file to a new name.
.IP "CMD 33: DELETE"
Implements the BASIC
.I XIO 33,#channel,aux1,aux2,\(lqH:filespec\(rq
command and attempts to remove (delete) the given files or patterns. It will
fail if the files are not user-readable, i.e. appear \(lqlocked\(rq in the emulator.
.IP "CMD 34: VALIDATE"
An extension following DOS 3 conventions also reachable within BASIC with
.I XIO 34,
this command will check whether the given filespec is well-formed and will
return an error code if not. It does not attempt to open any file.
.IP "CMD 35: UNPROTECT"
Implements the
.I XIO 35
command which \(lqunlocks\(rq the given file(s) and allows write-access into
it. The host system reflects this operation by enabling the user-writeable
permission bit.
.IP "CMD 36: PROTECT"
Implements the BASIC
.I XIO 36
command and \(lqlocks\(lq the filespec by removing the user write-permission
bit.
.IP "CMD 37: POINT"
Unlike command 32 to 36 above, this expects that the given channel is
already linked to an open stream. It implements the basic
.I POINT #ch,sector,byte
command for placing the file pointer within the file. The Os.
.B CIO
places the sector offset in AUX4 and AUX5 and the byte offset into
AUX3. However, conventions for file addressing are different from DOS 2.0S 
and are more orthogonal. The
.B H:
handler appears to have sectors of 256 bytes each, numbered linearly from 0
up within each file. Sectors are not global within the filing sytem but
local to the file linked to the channel. This is somewhat similar to the
DOS 3 implementation of
.I POINT.
.IP "CMD 38: NOTE"
Similar to command 37, this command expects an open stream on the same
channel, implementing the BASIC
.I NOTE #ch,sector,byte
command. It reads the file pointer within the opened file and returns byte
and sector offsets using the same conventions as
.I POINT.
Bytes are numbered consequently from 0 to 255, and sectors are numbered from
the start of the file from zero up, each of them but possibly the last
carrying 256 bytes of data. As long as programs use the values returned by 
.I NOTE
as opaque values and avoid to perform algebra on them, this remains
compatible to the DOS 2.0S. However, programs expecting 125 byte sectors and
absolute sectoring are likely to fail.
.IP "Unimplemented commands"
The
.B H:
device does not implement the various format commands for obvious reason. It
also doesn't implement some DOS 2.XL resp. DOS 3 extensions to load binary
files or to initialize a DOS. Especially, opening the DOS.SYS file for
writing will not perform anything special.
.SH THE BUILT-IN MONITOR
Atari++ comes with a build-in mini-monitor that can be helpful for debugging
programs, or for finding bugs in the emulator. The following section
describes briefly the front-end and the commands of this monitor, assuming
that the emulator has been compiled with
.I curses
support. Otherwise, the front-end is less user-friendly (or even more user
un-friendly than it used to be before, but that's another topic).
.SS ENTERING THE MONITOR
The monitor is entered either by pressing
.B F12
while the emulation is active, by pressing
.B ^C
in the shell that launched Atari++, or if the CPU core emulator crashes. The
crash could be either due to an instruction that is not implemented, an
instruction that would otherwise stop the CPU completely or an unstable
instruction whose function depends on some floating bus signals that are
hard or not at all emulatable. Other than that, Atari++ emulates all known
stable \(lqextra opcodes\)rq some lesser quality programs tend to use.

Another way of entering the monitor is due to hitting a break point, or by
finishing a single-stepped instruction.

.SS MONITOR COMMANDS
The monitor is entirely command line driven. Commands are four characters
long, non-case sensitive, with a possible abbreviation of one
character. Commands furthermore have an optional extension given by a dot
.B (.)
and a single additional character. This extender typically modifies the
command somewhat, or sets some parameter for the command, as for example the
output format. The extender for each command is remembered by the command
itself up to the next time the very same command is used. Hence, you won't
need to type the same extender every time. Using the question mark \(lq?\(rq
as extender lists the available extenders for the command.

Most commands also remember the last address they operated on. If typed
without arguments, they silently re-use the last address used. This is handy
for disassembling long routines since you just have to re-type the
disassembly command to continue the listing.

.SS ALGEBRAIC EXPRESSIONS
The monitor is capable of evaluating simple algebraic expressions in C
syntax containing the basic operators 
.B +,-,*,/, 
the binary operators
.B &,|,^,~
the logical operators
.B ||,&&,!
, the comparisons
.B <,<=,>=,==,!=
and the shifts
.B <<,>>.
The precedence of the operators follows mainly the C syntax except that
priority of the shifts has been \(lqfixed\(rq to follow more closely the (or
at least my) intuition, brackets are supported with their obvious meaning. 
Furthermore, the contents of the registers are available as the algebraic expressions
.B A,X,Y,P,S,PC. Otherwise, numerical constants are understood in hex
(sedecimal) notation.

A nice gymmick are the indirection operators
.B [],[].b,[].w
with the first two being equivalent. They evaluate their contents as an
address, and then return the contents of this (emulator) address as their
value. The first two are byte versions reading a single byte, the latter is
a word version that reads two bytes in little-endian notation to form a
sixteen bit integer.
.SS COMMAND DESCRIPTION
The following commands are available in the monitor:
.IP "HELP=?"
This command prints a command summary.
.IP "DUMP=D [expr]; extenders: A,S,V"
Dumps the memory contents at the address given by the argument or continuing
the last dump. The
.B A
extender switches to mixed hex-ATASCII output, emulating inverse video as much as
possible thru curses, the
.B S
extender uses hex-ANTIC screen code dumps. The
.B V
extender doesn't dump anything at all but rather sets the number of lines to
dump in one go.
.IP "EDIT=E [expr]; extenders: X,D,A,S,I"
Edit memory starting at the given address either in hex, decimal, ATASCII or
Antic Screen codes, respectively. For hex and decimal input, memory contents
are lines separated by blanks, and the input is aborted by an empty line,
i.e. by just pressing
.B RETURN.
For ATASCII and screen code editing, the text given as input is placed
directly in the memory of the Atari, possibly first converting to the target
format.
The
.B I
extender doesn't edit any memory but toggles the seventh bit of the ATASCII
resp. screen code entries on or off.
.IP "FILL=L addr size; extenders: X,D,A,S,I"
Fill the given memory range, given by base address and size with a byte
pattern. You will be prompted for the fill pattern separately in a second
stange: With the
.B X
extender, the byte pattern is given as a space-separated list of
hexadecimal (sedecimal) byte values, with the
.B D
extender, this pattern is given in decimal notation instead. Using the
.B A
extender allows to enter the bytes as ATASCII codes, and the
.B S
extender, last but not least, encodes the pattern in the ANTIC screen codes.

The 
.B I
extender toggles the seventh bit of the entered ATASCII or screen code
pattern on or off. Its setting is ignored for hex or decimal input.
.IP "MOVE=M from to size; extenders: S,C,A"
Move a memory block of the given size from the start location to the target
location. Source and target may overlap, the move command will be smart
enough to copy memory blocks correctly in all circumstances. The
.B S
extender will perform a simple memory copy operation within the current
address space, no matter which one has been selected by the 
.I ENVI
command (see below). The
.B C
extender, however, will move bytes from the selected address space into the
address space as seen from the 6502. This allows you to copy data from the
ANTIC space to the CPU space. The
.B A
extender works in the reverse direction by always writing into the ANTIC
space.
.IP "FIND=F [expr]; extenders: X,D,A,S,I,V"
Scans the memory starting at the given location for a byte pattern, possibly
filtering the pattern thru a mask. You are first prompted to enter the byte
string to look for, and then for a possible mask, that must be either left
blank or as long as the pattern entered first. If left blank, the byte
string in memory must match the entered string precisely for a
match. Otherwise, only the
.B one-bits
in the mask are significant and all zero bits in the mask are not compared
against the search pattern. This allows, for example, scanning for a text in
non-case-sensitive mode: Just set all pattern bytes to \(lq5F\(rq for
ignoring case and inverse video bits.

The extenders work similar to the extenders of the
.B EDIT
or
.B FILL
commands:
.B X
expects hexadecimal input,
.B D
requests decimal input,
.B A
allows ATASCII and
.B S
screen code patterns. The pattern mask, however, is always given in
hexadecimal notation. As always, the
.B I
extender toggles the seventh bit on or off for the 
.B A
and
.B S
extenders. Last but not least, the
.B V
extender defines the maximal number of matches that will be printed before
the search is aborted.
.IP "EVAL== expr; takes no extenders"
Evaluates its argument and prints the result on the screen.
.IP "BRKP=B [expr]; extenders: S,C,D,E,A,L"
Controls breakpoints. Once a breakpoint is hit, and the breakpoint is
enabled, the monitor is re-entered. Breakpoints can be set in either RAM or
ROM. They do not alter the memory at all but are rather emulated directly in
the CPU core. Hence, they cannot interact with software reading or
interpreting the code.

BRKP.S installs and activates a breakpoint at the address given by its
argument. BRKP.C removes it again. The 
.B D
and
.B E
extenders disable, resp. enable breakpoints that have been set before. A
disabled breakpoint is temporarely turned off, but remembered, and can be
turned on later on.

The
.B A
extender removes all breakpoints at once and the
.B L
extender lists all breakpoints and their status, i.e. wether they are
disabled or enabled.
.IP "DLST=A [expr]; extenders: L,S,V"
displays the antic
.I Display List
and the ANTIC status. The
.B L
extender prints a disassembly of the ANTIC program, or short the
.I Display List.
This is useful for getting an idea how the screen is generated. The
.B S
extender prints the contents of the ANTIC register set, for example to find
the start address of the display list. Finally, the
.B V
extender sets the number of lines the ANTIC disassembler prints in one go.
.IP "UNAS=U [expr]; extenders: L,V"
This is the 6502 disassembler. The
.B L
extender does exactly this; it disassembles at the address given by its
argument. The disassembler knows all \(lqextra instructions\(rq of the
6502 and prints them as four character rather than three character opcodes.

The
.B V
extender sets the number of lines the disassembler prints at a time.
.IP "RSET=P; extenders: W,C,I"
Various reset commands. The
.B W
extender warm-starts the emulator, the
.B C
extender runs into a coldstart. Both instructions also leave the monitor as
its full working environment is reset as well. If you need to debug 
instructions directly following the cold-start sequence, consider using the
.I -traceonreset on
command line switch.

Note that the warm-reset really holds the reset signal of the CPU. This is
unlike the 
.B Reset Console Key
on the Atari 800 and 400 models work; they just raise a special Antic NMI
signal and leave it to the Os to detect this signal and jump to the reset
vector. This kind of reset is reached with the
.B I
extender, though note that the detection of this NMI interrupt has been 
removed in Os ROM of the XL and XE models.
.IP "EXIT=X; no extenders"
Takes no arguments and no extenders and leaves the emulator immediately.
.IP "GOPG=G; extenders: P,M"
Takes no arguments and re-starts the emulation at the
current program counter value for the
.B P
extender. Hence, this leaves the monitor and continues emulation.
For the
.B M
extender, the emulation also continues, but the configuration menu is entered 
as soon as possible after leaving the monitor, as if
.I F1
has been pressed. This may take as long as a vertical retrace of the
emulated screen, and some code might have been run when the menu is 
entered.
.IP "STEP=Z; no extenders"
Similar to the 
.B GOPG
command, but the monitor is re-entered immediately after execution of the
command under the PC, printing the command that was executed last. This is
most useful for debugging purposes and single-stepping thru critical
sections of a program.
.IP "NEXT=N; no extenders"
Similar to
.B NEXT
though this command does not step into subroutines. For any operation that
places data onto the hardware stack, this command will run the program up 
to the location where the data is again popped from the stack; this data is
typically the return address of a
.I JSR
call, but
.B NEXT
can also be used to find the matching
.I PLA
of a 
.I PHA.
.IP "STAT=T [comp]; extenders: L,S"
Prints status information about various system components, including
internal hardware register sets, port settings and configuration. The
.B L
extender lists all system components for which a status information is
available, and 
.B STAT.S
followed by the name of this component prints the status of the mentioned
component.
.IP "SETR=S register=expr; no extenders"
Sets a CPU register to a specified value given by an expression. The syntax
of this command is non-standard for convenience reasons. Register and
desired register contents are separated by an equals sign, and not by a
blank. For example,
.B SETR A=ff
would set the contents of the accumulator to 255=0xff.
.IP "REGS=R; no extenders"
displays the contents of the CPU in a brief listing. This command is ideal
for the
.B SPLT
command explained next.
.IP "SPLT=/ [cmds]; extenders: C,S"
This command is special as it modifies the behaviour of the monitor and does
not perform a direct action on the emulation components. The
.B S
extender splits
off the top part of the monitor output window and prints there the contents
of the commands following the SPLT command. For example,
.B SPLT.S R
would continously display the register dump of the 6502 CPU on top of the
screen.

Several commands can be run at once by separating them with a colon.
The split-off output is updated on each command, making the screen splitting
an ideal feature for the single stepping and debugging. The
.B C
extender cleans and removes this split-off part of the screen again.
.IP "ENVI=V [value]; extenders: A"
Controls various (currently one) monitor environment settings. The
.B A
extender controls the view on the memory. As the 130XE offers 128K of memory
that can be selectively banked for the CPU and for ANTIC, it matters whether
the memory is seen by the CPU or by ANTIC as both may have selected
different banks for it. This environment switch toggles the view of the
monitor onto the memory as either comming from ANTIC or from the CPU.
.SH FILES
.IP "/etc/atari++/atari++.conf"
The system global configuration files
.IP "~/.atari++.conf"
The user specific configuration file
.IP "./.atari++.conf"
The directory specific configuration file.
.SH ENVIRONMENT VARIABLES
No emulator specific variables. Atari++ is controlled completely by its
configuration files and command line arguments.
.SH CREDITS
David Firth for his Atari800 emulator. Atari++ is not based on this
earlier work, though influenced. Atari++ was entirely and completely
rewritten from scratch, in C++, avoiding some of the constructional
difficulties of David's work. Especially, the way how graphics output is
constructed and how player/missile graphic priorities are generated is quite
different from his implementation.

Ron Fries for the Pokey emulation routine that got used in early releases of
the Atari800 emulator. The strategy that has been utilized for sound
build-up has been used in the pokey emulation of this emulator as well,
though the implementation details are a bit different and the overall
quality of the sound emulation has been improved heavily. Specifically,
high-pass filters, sound muting and anti-aliasing are new to the emulation
model.

Jean-loup Gailly and Mark Adler for the Z compression library that gets
used if available for .gz compressed disk images.

Sam Lantinga and the SDL group for the Simple DirectMedia Layer library, or
short, SDL, that offers one of the possible front-ends of the Atari++
emulator if it is available.

Jindroush and the Atari Cartridge Dumping project for providing
insight into the details of the cart emulation. Specifically, SDX and
XEGS cart emulation would have been impossible without him.

Petr Stehlik and the remaining atari800 team for cooperation and for working
out the licencing conditions of this emulator. Specifically, I thank Petr for
keeping cool in the hot days of working out all the details of making this
project available.

Andreas Magenheimer and the ABBUC team for providing some hardware insight
that was otherwise not available. Specifically, emulation of various bank
switching logics is due to ABBUC.

Jason Duerstock's for its analyzation of the RT8 cartridge. Unfortunately,
something seems to be still not quite right with it. The current 
implementation in Atari++ uses a somewhat different route how the register
assignment might work. This is all an educated guess, though.

.SH REFERENCES
.IP "DE RE ATARI"
by John Eckstrom, Michael A. Eckberg, Gus Makreas, Lane Winner and Elizabeth
Hernaton.
.IP "Das Atari Profibuch"
by Julian Reschke and Andreas Wiethoff, Sybex, 1985.
.IP "6502 Assembly Language Programming"
by Lance A. Leventhal, McGraw-Hill, 1979.
.IP "Atari Technical Documentation"
from 
.I The Atari Historical Society
at www.atari-history.com
.SH AUTHOR
Thomas Richter (thor@math.tu-berlin.de)
.SH SEE ALSO
An Atari800. 

